/*
 * Copyright 2018 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.lettuce.core.cluster;

import static org.assertj.core.api.Assertions.assertThat;

import java.util.Collection;
import java.util.List;

import javax.inject.Inject;

import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;

import io.lettuce.core.api.StatefulRedisConnection;
import io.lettuce.core.api.sync.RedisCommands;
import io.lettuce.core.models.command.CommandDetail;
import io.lettuce.core.models.command.CommandDetailParser;
import io.lettuce.core.protocol.CommandType;
import io.lettuce.core.protocol.ProtocolKeyword;
import io.lettuce.test.LettuceExtension;

/**
 * @author Mark Paluch
 */
@ExtendWith(LettuceExtension.class)
public class RedisStateIntegrationTests {

    private final RedisCommands<String, String> redis;

    @Inject
    RedisStateIntegrationTests(StatefulRedisConnection<String, String> connection) {
        this.redis = connection.sync();
    }

    @Test
    void shouldDiscoverCommands() {

        List<CommandDetail> commandDetails = CommandDetailParser.parse(redis.command());
        RedisState state = new RedisState(commandDetails);

        assertThat(state).extracting("availableCommands").flatExtracting(it -> (Collection<Object>) it)
                .contains(CommandType.GEOADD).doesNotContain(UnknownCommand.FOO);

        assertThat(state.hasCommand(CommandType.GEOADD)).isTrue();
        assertThat(state.hasCommand(UnknownCommand.FOO)).isFalse();
    }

    enum UnknownCommand implements ProtocolKeyword {

        FOO;

        @Override
        public byte[] getBytes() {
            return name().getBytes();
        }
    }
}
